==> sal-cluster-admin-api-1.9.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/params/xml/ns/yang/controller/md/sal/cluster/admin/rev151013/RemoveAllShardReplicasInputBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.controller.md.sal.cluster.admin.rev151013;
import com.google.common.base.MoreObjects;
import com.google.common.collect.ImmutableMap;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link RemoveAllShardReplicasInputBuilder} instances.
 *
 * @see RemoveAllShardReplicasInputBuilder
 *
 */
public class RemoveAllShardReplicasInputBuilder implements Builder<RemoveAllShardReplicasInput> {

    private String _memberName;


    Map<Class<? extends Augmentation<RemoveAllShardReplicasInput>>, Augmentation<RemoveAllShardReplicasInput>> augmentation = Collections.emptyMap();

    public RemoveAllShardReplicasInputBuilder() {
    }

    public RemoveAllShardReplicasInputBuilder(RemoveAllShardReplicasInput base) {
        this._memberName = base.getMemberName();
        if (base instanceof RemoveAllShardReplicasInputImpl) {
            RemoveAllShardReplicasInputImpl impl = (RemoveAllShardReplicasInputImpl) base;
            if (!impl.augmentation.isEmpty()) {
                this.augmentation = new HashMap<>(impl.augmentation);
            }
        } else if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<RemoveAllShardReplicasInput>>, Augmentation<RemoveAllShardReplicasInput>> aug =((AugmentationHolder<RemoveAllShardReplicasInput>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
    }


    public String getMemberName() {
        return _memberName;
    }
    
    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<RemoveAllShardReplicasInput>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public RemoveAllShardReplicasInputBuilder setMemberName(final String value) {
        this._memberName = value;
        return this;
    }
    
    public RemoveAllShardReplicasInputBuilder addAugmentation(Class<? extends Augmentation<RemoveAllShardReplicasInput>> augmentationType, Augmentation<RemoveAllShardReplicasInput> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public RemoveAllShardReplicasInputBuilder removeAugmentation(Class<? extends Augmentation<RemoveAllShardReplicasInput>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public RemoveAllShardReplicasInput build() {
        return new RemoveAllShardReplicasInputImpl(this);
    }

    private static final class RemoveAllShardReplicasInputImpl implements RemoveAllShardReplicasInput {
    
        private final String _memberName;
    
        private Map<Class<? extends Augmentation<RemoveAllShardReplicasInput>>, Augmentation<RemoveAllShardReplicasInput>> augmentation = Collections.emptyMap();
    
        RemoveAllShardReplicasInputImpl(RemoveAllShardReplicasInputBuilder base) {
            this._memberName = base.getMemberName();
            this.augmentation = ImmutableMap.copyOf(base.augmentation);
        }
    
        @Override
        public Class<RemoveAllShardReplicasInput> getImplementedInterface() {
            return RemoveAllShardReplicasInput.class;
        }
    
        @Override
        public String getMemberName() {
            return _memberName;
        }
        
        @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
        @Override
        public <E$$ extends Augmentation<RemoveAllShardReplicasInput>> E$$ augmentation(Class<E$$> augmentationType) {
            return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_memberName);
            result = prime * result + Objects.hashCode(augmentation);
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!RemoveAllShardReplicasInput.class.equals(((DataObject)obj).getImplementedInterface())) {
                return false;
            }
            RemoveAllShardReplicasInput other = (RemoveAllShardReplicasInput)obj;
            if (!Objects.equals(_memberName, other.getMemberName())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                RemoveAllShardReplicasInputImpl otherImpl = (RemoveAllShardReplicasInputImpl) obj;
                if (!Objects.equals(augmentation, otherImpl.augmentation)) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<RemoveAllShardReplicasInput>>, Augmentation<RemoveAllShardReplicasInput>> e : augmentation.entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("RemoveAllShardReplicasInput");
            CodeHelpers.appendValue(helper, "_memberName", _memberName);
            CodeHelpers.appendValue(helper, "augmentation", augmentation.values());
            return helper.toString();
        }
    }
}

==> sal-cluster-admin-api-1.10.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/params/xml/ns/yang/controller/md/sal/cluster/admin/rev151013/RemoveAllShardReplicasInputBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.controller.md.sal.cluster.admin.rev151013;
import com.google.common.base.MoreObjects;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link RemoveAllShardReplicasInputBuilder} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     RemoveAllShardReplicasInputBuilder createTarget(int fooXyzzy, int barBaz) {
 *         return new RemoveAllShardReplicasInputBuilderBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of RemoveAllShardReplicasInputBuilder, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization oportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see RemoveAllShardReplicasInputBuilder
 * @see Builder
 *
 */
public class RemoveAllShardReplicasInputBuilder implements Builder<RemoveAllShardReplicasInput> {

    private String _memberName;


    Map<Class<? extends Augmentation<RemoveAllShardReplicasInput>>, Augmentation<RemoveAllShardReplicasInput>> augmentation = Collections.emptyMap();

    public RemoveAllShardReplicasInputBuilder() {
    }

    public RemoveAllShardReplicasInputBuilder(RemoveAllShardReplicasInput base) {
        if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<RemoveAllShardReplicasInput>>, Augmentation<RemoveAllShardReplicasInput>> aug =((AugmentationHolder<RemoveAllShardReplicasInput>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
        this._memberName = base.getMemberName();
    }


    public String getMemberName() {
        return _memberName;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<RemoveAllShardReplicasInput>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public RemoveAllShardReplicasInputBuilder setMemberName(final String value) {
        this._memberName = value;
        return this;
    }
    
    public RemoveAllShardReplicasInputBuilder addAugmentation(Class<? extends Augmentation<RemoveAllShardReplicasInput>> augmentationType, Augmentation<RemoveAllShardReplicasInput> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public RemoveAllShardReplicasInputBuilder removeAugmentation(Class<? extends Augmentation<RemoveAllShardReplicasInput>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public RemoveAllShardReplicasInput build() {
        return new RemoveAllShardReplicasInputImpl(this);
    }

    private static final class RemoveAllShardReplicasInputImpl
        extends AbstractAugmentable<RemoveAllShardReplicasInput>
        implements RemoveAllShardReplicasInput {
    
        private final String _memberName;
    
        RemoveAllShardReplicasInputImpl(RemoveAllShardReplicasInputBuilder base) {
            super(base.augmentation);
            this._memberName = base.getMemberName();
        }
    
        @Override
        public String getMemberName() {
            return _memberName;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_memberName);
            result = prime * result + Objects.hashCode(augmentations());
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!RemoveAllShardReplicasInput.class.equals(((DataObject)obj).implementedInterface())) {
                return false;
            }
            RemoveAllShardReplicasInput other = (RemoveAllShardReplicasInput)obj;
            if (!Objects.equals(_memberName, other.getMemberName())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                RemoveAllShardReplicasInputImpl otherImpl = (RemoveAllShardReplicasInputImpl) obj;
                if (!Objects.equals(augmentations(), otherImpl.augmentations())) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<RemoveAllShardReplicasInput>>, Augmentation<RemoveAllShardReplicasInput>> e : augmentations().entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("RemoveAllShardReplicasInput");
            CodeHelpers.appendValue(helper, "_memberName", _memberName);
            CodeHelpers.appendValue(helper, "augmentation", augmentations().values());
            return helper.toString();
        }
    }
}
